Cursor

Struct Cursor 

pub struct Cursor { /* private fields */ }
A specific position inside a Reader.

Implementations

Source

impl Cursor

pub fn byte_offset(&self) -> usize

The position of the Cursor in bytes.

pub fn char_offset(&self) -> usize

The position of the Cursor in characters.

pub fn line(&self) -> usize

The line number in which the Cursor is placed. It starts at line 1.

pub fn column(&self) -> usize

The column number in which the Cursor is placed. It starts at column 1.